@@ -8,10 +8,15 @@ var path = require('path')
 var fs = require('fs')
 
 t.jobs = 8
-glob.sync(__dirname + '/fixtures/*.tap').forEach(function (tapfile) {
-  const tapContent = fs.readFileSync(tapfile, 'utf8')
-  t.jobs = 4
-  t.test(path.basename(tapfile), { buffer: true }, t => {
+const tapFiles = fs.readdirSync(__dirname + '/fixtures')
+  .filter(f => /\.tap$/.test(f))
+
+for (const tapFile of tapFiles) {
+  const f = `${__dirname}/fixtures/${tapFile}`
+  t.test(tapFile, async t => {
+    t.snapshotFile = path.resolve(__dirname, '..', `tap-snapshots/test/parser-stringify/${tapFile}.test.cjs`)
+    t.plan(4)
+    const tapContent = await fs.promises.readFile(f, 'utf8')
     t.test('default settings', t => {
       const res = Parser.parse(tapContent)
       t.matchSnapshot(res, 'parsed')
@@ -36,6 +41,5 @@ glob.sync(__dirname + '/fixtures/*.tap').forEach(function (tapfile) {
         t.end()
       })
     }
-    t.end()
   })
-})
+}
